diff --git a/src/main/java/edu/ntnu/stud/chaosgame/game/ChaosCanvas.java b/src/main/java/edu/ntnu/stud/chaosgame/game/ChaosCanvas.java
deleted file mode 100644
index bae6e16076d90cefcd6d1ed82403a37c818c6b8d..0000000000000000000000000000000000000000
--- a/src/main/java/edu/ntnu/stud/chaosgame/game/ChaosCanvas.java
+++ /dev/null
@@ -1,4 +0,0 @@
-package edu.ntnu.stud.chaosgame.game;
-
-public class ChaosCanvas {
-}
diff --git a/src/main/java/edu/ntnu/stud/chaosgame/game/ChaosGame.java b/src/main/java/edu/ntnu/stud/chaosgame/game/ChaosGame.java
deleted file mode 100644
index 8090e64daf796983244860263cddb74daf9d6a72..0000000000000000000000000000000000000000
--- a/src/main/java/edu/ntnu/stud/chaosgame/game/ChaosGame.java
+++ /dev/null
@@ -1,4 +0,0 @@
-package edu.ntnu.stud.chaosgame.game;
-
-public class ChaosGame {
-}
diff --git a/src/main/java/edu/ntnu/stud/chaosgame/game/ChaosGameFileHandler.java b/src/main/java/edu/ntnu/stud/chaosgame/game/ChaosGameFileHandler.java
index d7fd4c9fb9aab35cf1c137c1da2d9a9a011625e1..d8be744741a5d88647115fd2fa4f90cd4f1f6db3 100644
--- a/src/main/java/edu/ntnu/stud/chaosgame/game/ChaosGameFileHandler.java
+++ b/src/main/java/edu/ntnu/stud/chaosgame/game/ChaosGameFileHandler.java
@@ -3,9 +3,9 @@ package edu.ntnu.stud.chaosgame.game;
 import edu.ntnu.stud.chaosgame.model.Complex;
 import edu.ntnu.stud.chaosgame.model.Matrix2x2;
 import edu.ntnu.stud.chaosgame.model.Vector2D;
-import edu.ntnu.stud.chaosgame.transformations.AffineTransform2D;
-import edu.ntnu.stud.chaosgame.transformations.JuliaTransform;
-import edu.ntnu.stud.chaosgame.transformations.Transform2D;
+import edu.ntnu.stud.chaosgame.model.transformations.AffineTransform2D;
+import edu.ntnu.stud.chaosgame.model.transformations.JuliaTransform;
+import edu.ntnu.stud.chaosgame.model.transformations.Transform2D;
 import java.io.FileNotFoundException;
 import java.io.FileWriter;
 import java.io.IOException;
diff --git a/src/test/java/edu/ntnu/stud/chaosgame/transformations/AffineTransform2DTest.java b/src/test/java/edu/ntnu/stud/chaosgame/transformations/AffineTransform2DTest.java
index 43a456448882d436c05101a536b064c0cba2ad74..e772ed44558f303382b1d4bf8048572baa8eb415 100644
--- a/src/test/java/edu/ntnu/stud/chaosgame/transformations/AffineTransform2DTest.java
+++ b/src/test/java/edu/ntnu/stud/chaosgame/transformations/AffineTransform2DTest.java
@@ -28,7 +28,7 @@ class AffineTransform2DTest {
     }
     @Nested
     @DisplayName("Positive Affine Transform Tests")
-    class PositiveAffineTransform2DTest{
+    class PositiveAffineTransform2DTest {
         @Test
         void transform() {
             Vector2D point = new Vector2D(1, 1);
diff --git a/src/main/java/edu/ntnu/stud/chaosgame/game/ChaosGameDescription.java b/src/main/java/edu/ntnu/stud/chaosgame/game/ChaosGameDescription.java
index 2b3e0782b20d2e1839be1942750f18daf0c00e8a..a7c66558e4968275cdb722b58f99b66b4611c2a1 100644
--- a/src/main/java/edu/ntnu/stud/chaosgame/game/ChaosGameDescription.java
+++ b/src/main/java/edu/ntnu/stud/chaosgame/game/ChaosGameDescription.java
@@ -1,22 +1,23 @@
 package edu.ntnu.stud.chaosgame.game;
 
 import edu.ntnu.stud.chaosgame.model.Vector2D;
-import edu.ntnu.stud.chaosgame.transformations.Transform2D;
+import edu.ntnu.stud.chaosgame.model.AffineTransform2D;
 
 import java.util.List;
 
 public class ChaosGameDescription {
     private final Vector2D minCoords;
     private final Vector2D maxCoords;
-    private final List<Transform2D> transforms;
+
+  private final List<AffineTransform2D> transforms;
 
     /**
      * Constructor for ChaosGameDescription
      * @param minCoords Inputs a {@link Vector2D} vector of lower left coordinates for the chaos game.
      * @param maxCoords Inputs a {@link Vector2D} vector of upper right coordinates for the chaos game.
      * @param transforms Inputs a list of transformations {@link Transform2D} used in the chaos game.
      */
-    public ChaosGameDescription(Vector2D minCoords, Vector2D maxCoords, List<Transform2D> transforms) {
+    public ChaosGameDescription(Vector2D minCoords, Vector2D maxCoords, List<AffineTransform2D> transforms) {
         if (minCoords == null || maxCoords == null || transforms == null){
             throw new IllegalArgumentException("Coordinates and transforms must not be null.");
         }
@@ -29,7 +30,7 @@ public class ChaosGameDescription {
      * Getter method for transforms
      * @return Returns a list of transforms in the chaos game.
      */
-    public List<Transform2D> getTransforms(){
+    public List<AffineTransform2D> getTransforms(){
         return transforms;
     }
     /**
@@ -1,22 +1,23 @@
      * @param minCoords Inputs a {@link Vector2D} vector of lower left coordinates for the chaos game.
      * @param maxCoords Inputs a {@link Vector2D} vector of upper right coordinates for the chaos game.
-     * @param transforms Inputs a list of transformations {@link Transform2D} used in the chaos game.
+     * @param transforms Inputs a list of transformations {@link AffineTransform2D} used in the chaos game.
      */